<template>
  <div class="card">
    <div class="card-body">
      <h4
        class="card-title"
        :class="$i18n.locale == 'ar' ? 'font-size-15' : ''"
      >
        {{ label }}
      </h4>

      <div class="col-md-12 text-center" style="padding: 0">
        <span
          v-if="dataLoading"
          class="spinner-grow spinner-grow-sm mr-1"
          role="status"
          aria-hidden="true"
        >
        </span>

        <multiselect
          :class="$i18n.locale == 'ar' ? 'dir-rtl' : ''"
          :style="$i18n.locale == 'ar' ? 'text-align:right' : ''"
          @remove="onRemove"
          @select="onSelect"
          @search-change="fetchData"
          track-by="id"
          :loading="dataLoading"
          label="title"
          :id="'multiselect' + refs"
          :ref="'multiselectRef' + refs"
          autocomplete="on"
          selectLabel=""
          v-model="row.select_ids"
          :options="data"
          :multiple="true"
          :close-on-select="false"
          :clear-on-select="false"
          :hide-selected="true"
          :preserve-search="true"
          :taggable="false"
          :searchable="true"
          :placeholder="$t('view.select_elements')"
        >
          <template v-slot:noResult>
            <span
              :class="'option__desc ' + ($i18n.locale == 'ar') ? 'dir-rtl' : ''"
            >
              <span class="option__title">
                {{ $t("app.no_data") }}
              </span>
            </span>
          </template>
          <template v-slot:noOptions>
            <span
              :class="'option__desc ' + ($i18n.locale == 'ar') ? 'dir-rtl' : ''"
            >
              <span class="option__title">
                {{ $t("app.no_data") }}
              </span>
            </span>
          </template>
        </multiselect>
      </div>
    </div>
  </div>
</template>

<script>
import iziToast from "izitoast";
import Multiselect from "vue-multiselect";

export default {
  name: "CardMultiSelect",
  props: ["label", "select_ids", "category_id", "refs", "parents"],
  components: {
    Multiselect,
  },
  data() {
    return {
      auth: {
        role: "",
        id_token: "",
      },
      row: {
        select_ids: this.$props.select_ids ?? [],
      },
      get_parents: this.$props.parents,
      current_category_id: this.$props.category_id,
      data: [],
      dataLoading: true,
    };
  },
  created() {
    if (localStorage.getItem("role_key")) {
      this.auth.role = localStorage.getItem("role_key");
    }
    if (localStorage.getItem("id_token")) {
      this.auth.id_token = localStorage.getItem("id_token");
    }

    this.fetchData();
  },
  methods: {
    onRemove(removedOption) {
      var select_ids = [];
      this.row.select_ids.filter((option) => {
        if (option.id != removedOption.id) select_ids.push(option.id);
      });
      this.$emit("selectChange", {
        select_ids,
      });
    },

    onSelect(selectedOption) {
      var select_ids = [];
      this.row.select_ids.filter((option) => {
        select_ids.push(option.id);
      });

      select_ids.push(selectedOption.id);

      this.$emit("selectChange", {
        select_ids,
      });
    },

    fetchData: function (search = "") {
      this.dataLoading = true;
      this.axios.defaults.headers.common = {
        "X-Requested-With": "XMLHttpRequest", // security to prevent CSRF attacks
        Authorization: `Bearer ` + this.auth.id_token,
      };

      const options = {
        url: this.refs,
        method: "GET",
        data: {},
        params: {
          search,
          category_id: this.current_category_id,
          get_parents: this.get_parents,
          paginate: 1000,
        },
      };
      this.axios(options)
        .then((res) => {
          this.dataLoading = false;
          this.data = [];
          res.data.data.rows.filter((row) => {
            this.data.push({ id: row.id, title: row.title });
          });
        })
        .catch((err) => {
          this.dataLoading = false;
          iziToast.warning({
            icon: "bx bx-angry",
            title: "",
            message: err.response ? err.response.data.message : "" + err,
          });
        });
    },
  },
};
</script>

<style src="vue-multiselect/dist/vue-multiselect.min.css"></style>
